==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/logic/kotlin/inputs/X12SecuritySettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.inputs

import com.pulumi.azurenative.logic.inputs.X12SecuritySettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The X12 agreement security settings.
 * @property authorizationQualifier The authorization qualifier.
 * @property authorizationValue The authorization value.
 * @property passwordValue The password value.
 * @property securityQualifier The security qualifier.
 */
public data class X12SecuritySettingsArgs(
    public val authorizationQualifier: Output<String>,
    public val authorizationValue: Output<String>? = null,
    public val passwordValue: Output<String>? = null,
    public val securityQualifier: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.logic.inputs.X12SecuritySettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.logic.inputs.X12SecuritySettingsArgs =
        com.pulumi.azurenative.logic.inputs.X12SecuritySettingsArgs.builder()
            .authorizationQualifier(authorizationQualifier.applyValue({ args0 -> args0 }))
            .authorizationValue(authorizationValue?.applyValue({ args0 -> args0 }))
            .passwordValue(passwordValue?.applyValue({ args0 -> args0 }))
            .securityQualifier(securityQualifier.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [X12SecuritySettingsArgs].
 */
@PulumiTagMarker
public class X12SecuritySettingsArgsBuilder internal constructor() {
    private var authorizationQualifier: Output<String>? = null

    private var authorizationValue: Output<String>? = null

    private var passwordValue: Output<String>? = null

    private var securityQualifier: Output<String>? = null

    /**
     * @param value The authorization qualifier.
     */
    @JvmName("ifmwgywufcypwoby")
    public suspend fun authorizationQualifier(`value`: Output<String>) {
        this.authorizationQualifier = value
    }

    /**
     * @param value The authorization value.
     */
    @JvmName("kxpctftbpwuwtqek")
    public suspend fun authorizationValue(`value`: Output<String>) {
        this.authorizationValue = value
    }

    /**
     * @param value The password value.
     */
    @JvmName("tccutiipvramtask")
    public suspend fun passwordValue(`value`: Output<String>) {
        this.passwordValue = value
    }

    /**
     * @param value The security qualifier.
     */
    @JvmName("lqofjlgmejmcyvlf")
    public suspend fun securityQualifier(`value`: Output<String>) {
        this.securityQualifier = value
    }

    /**
     * @param value The authorization qualifier.
     */
    @JvmName("atnsahgfmyyagjkh")
    public suspend fun authorizationQualifier(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.authorizationQualifier = mapped
    }

    /**
     * @param value The authorization value.
     */
    @JvmName("ejnrcexrnrhmdgsh")
    public suspend fun authorizationValue(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.authorizationValue = mapped
    }

    /**
     * @param value The password value.
     */
    @JvmName("wlffxhwtofkndpbr")
    public suspend fun passwordValue(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.passwordValue = mapped
    }

    /**
     * @param value The security qualifier.
     */
    @JvmName("yfysmrraaynmrywh")
    public suspend fun securityQualifier(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.securityQualifier = mapped
    }

    internal fun build(): X12SecuritySettingsArgs = X12SecuritySettingsArgs(
        authorizationQualifier = authorizationQualifier ?: throw
            PulumiNullFieldException("authorizationQualifier"),
        authorizationValue = authorizationValue,
        passwordValue = passwordValue,
        securityQualifier = securityQualifier ?: throw PulumiNullFieldException("securityQualifier"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/logic/kotlin/inputs/X12SecuritySettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.inputs

import com.pulumi.azurenative.logic.inputs.X12SecuritySettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The X12 agreement security settings.
 * @property authorizationQualifier The authorization qualifier.
 * @property authorizationValue The authorization value.
 * @property passwordValue The password value.
 * @property securityQualifier The security qualifier.
 */
public data class X12SecuritySettingsArgs(
    public val authorizationQualifier: Output<String>,
    public val authorizationValue: Output<String>? = null,
    public val passwordValue: Output<String>? = null,
    public val securityQualifier: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.logic.inputs.X12SecuritySettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.logic.inputs.X12SecuritySettingsArgs =
        com.pulumi.azurenative.logic.inputs.X12SecuritySettingsArgs.builder()
            .authorizationQualifier(authorizationQualifier.applyValue({ args0 -> args0 }))
            .authorizationValue(authorizationValue?.applyValue({ args0 -> args0 }))
            .passwordValue(passwordValue?.applyValue({ args0 -> args0 }))
            .securityQualifier(securityQualifier.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [X12SecuritySettingsArgs].
 */
@PulumiTagMarker
public class X12SecuritySettingsArgsBuilder internal constructor() {
    private var authorizationQualifier: Output<String>? = null

    private var authorizationValue: Output<String>? = null

    private var passwordValue: Output<String>? = null

    private var securityQualifier: Output<String>? = null

    /**
     * @param value The authorization qualifier.
     */
    @JvmName("wthhcgrvfnaktxpu")
    public suspend fun authorizationQualifier(`value`: Output<String>) {
        this.authorizationQualifier = value
    }

    /**
     * @param value The authorization value.
     */
    @JvmName("xbvcbtqhgqclrxuo")
    public suspend fun authorizationValue(`value`: Output<String>) {
        this.authorizationValue = value
    }

    /**
     * @param value The password value.
     */
    @JvmName("anfmluiwjuioucyw")
    public suspend fun passwordValue(`value`: Output<String>) {
        this.passwordValue = value
    }

    /**
     * @param value The security qualifier.
     */
    @JvmName("hakmawkojsbxehag")
    public suspend fun securityQualifier(`value`: Output<String>) {
        this.securityQualifier = value
    }

    /**
     * @param value The authorization qualifier.
     */
    @JvmName("gfscodmqgnmggxij")
    public suspend fun authorizationQualifier(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.authorizationQualifier = mapped
    }

    /**
     * @param value The authorization value.
     */
    @JvmName("fmhlvksnxnotexvh")
    public suspend fun authorizationValue(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.authorizationValue = mapped
    }

    /**
     * @param value The password value.
     */
    @JvmName("ljnjtmqguybsqrkf")
    public suspend fun passwordValue(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.passwordValue = mapped
    }

    /**
     * @param value The security qualifier.
     */
    @JvmName("ktnbqyqhvxvnfwmt")
    public suspend fun securityQualifier(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.securityQualifier = mapped
    }

    internal fun build(): X12SecuritySettingsArgs = X12SecuritySettingsArgs(
        authorizationQualifier = authorizationQualifier ?: throw
            PulumiNullFieldException("authorizationQualifier"),
        authorizationValue = authorizationValue,
        passwordValue = passwordValue,
        securityQualifier = securityQualifier ?: throw PulumiNullFieldException("securityQualifier"),
    )
}
